==> postgresql_7.2.orig.tar.gz: postgresql-7.2/src/interfaces/ecpg/preproc/preproc.h <==
#ifndef Y_TAB_H
# define Y_TAB_H

typedef union {
	double                  dval;
	int                     ival;
	char *                  str;
	struct when             action;
	struct index		index;
	int			tagname;
	struct this_type	type;
	enum ECPGttype		type_enum;
	enum ECPGdtype		dtype_enum;
	struct fetch_desc	descriptor;
} YYSTYPE;
# define	SQL_ALLOCATE	257
# define	SQL_AUTOCOMMIT	258
# define	SQL_BOOL	259
# define	SQL_BREAK	260
# define	SQL_CALL	261
# define	SQL_CARDINALITY	262
# define	SQL_CONNECT	263
# define	SQL_CONNECTION	264
# define	SQL_CONTINUE	265
# define	SQL_COUNT	266
# define	SQL_DATA	267
# define	SQL_DATETIME_INTERVAL_CODE	268
# define	SQL_DATETIME_INTERVAL_PRECISION	269
# define	SQL_DEALLOCATE	270
# define	SQL_DESCRIPTOR	271
# define	SQL_DISCONNECT	272
# define	SQL_ENUM	273
# define	SQL_FOUND	274
# define	SQL_FREE	275
# define	SQL_GET	276
# define	SQL_GO	277
# define	SQL_GOTO	278
# define	SQL_IDENTIFIED	279
# define	SQL_INDICATOR	280
# define	SQL_INT	281
# define	SQL_KEY_MEMBER	282
# define	SQL_LENGTH	283
# define	SQL_LONG	284
# define	SQL_NAME	285
# define	SQL_NULLABLE	286
# define	SQL_OCTET_LENGTH	287
# define	SQL_OPEN	288
# define	SQL_PREPARE	289
# define	SQL_RELEASE	290
# define	SQL_REFERENCE	291
# define	SQL_RETURNED_LENGTH	292
# define	SQL_RETURNED_OCTET_LENGTH	293
# define	SQL_SCALE	294
# define	SQL_SECTION	295
# define	SQL_SHORT	296
# define	SQL_SIGNED	297
# define	SQL_SQL	298
# define	SQL_SQLERROR	299
# define	SQL_SQLPRINT	300
# define	SQL_SQLWARNING	301
# define	SQL_START	302
# define	SQL_STOP	303
# define	SQL_STRUCT	304
# define	SQL_UNSIGNED	305
# define	SQL_VALUE	306
# define	SQL_VAR	307
# define	SQL_WHENEVER	308
# define	S_ADD	309
# define	S_AND	310
# define	S_ANYTHING	311
# define	S_AUTO	312
# define	S_CONST	313
# define	S_DEC	314
# define	S_DIV	315
# define	S_DOTPOINT	316
# define	S_EQUAL	317
# define	S_EXTERN	318
# define	S_INC	319
# define	S_LSHIFT	320
# define	S_MEMPOINT	321
# define	S_MEMBER	322
# define	S_MOD	323
# define	S_MUL	324
# define	S_NEQUAL	325
# define	S_OR	326
# define	S_REGISTER	327
# define	S_RSHIFT	328
# define	S_STATIC	329
# define	S_SUB	330
# define	S_VOLATILE	331
# define	TYPECAST	332
# define	ABSOLUTE	333
# define	ACTION	334
# define	ADD	335
# define	ALL	336
# define	ALTER	337
# define	AND	338
# define	ANY	339
# define	AS	340
# define	ASC	341
# define	AT	342
# define	AUTHORIZATION	343
# define	BEGIN_TRANS	344
# define	BETWEEN	345
# define	BOTH	346
# define	BY	347
# define	CASCADE	348
# define	CASE	349
# define	CAST	350
# define	CHAIN	351
# define	CHAR	352
# define	CHARACTER	353
# define	CHARACTERISTICS	354
# define	CHECK	355
# define	CLOSE	356
# define	COALESCE	357
# define	COLLATE	358
# define	COLUMN	359
# define	COMMIT	360
# define	CONSTRAINT	361
# define	CONSTRAINTS	362
# define	CREATE	363
# define	CROSS	364
# define	CURRENT	365
# define	CURRENT_DATE	366
# define	CURRENT_TIME	367
# define	CURRENT_TIMESTAMP	368
# define	CURRENT_USER	369
# define	CURSOR	370
# define	DAY_P	371
# define	DEC	372
# define	DECIMAL	373
# define	DECLARE	374
# define	DEFAULT	375
# define	DELETE	376
# define	DESC	377
# define	DISTINCT	378
# define	DOUBLE	379
# define	DROP	380
# define	ELSE	381
# define	ENCRYPTED	382
# define	END_TRANS	383
# define	EXCEPT	384
# define	EXECUTE	385
# define	EXISTS	386
# define	EXTRACT	387
# define	FALSE_P	388
# define	FETCH	389
# define	FLOAT	390
# define	FOR	391
# define	FOREIGN	392
# define	FROM	393
# define	FULL	394
# define	GLOBAL	395
# define	GRANT	396
# define	GROUP	397
# define	HAVING	398
# define	HOUR_P	399
# define	IN	400
# define	INNER_P	401
# define	INOUT	402
# define	INSENSITIVE	403
# define	INSERT	404
# define	INTERSECT	405
# define	INTERVAL	406
# define	INTO	407
# define	IS	408
# define	ISOLATION	409
# define	JOIN	410
# define	KEY	411
# define	LANGUAGE	412
# define	LEADING	413
# define	LEFT	414
# define	LEVEL	415
# define	LIKE	416
# define	LOCAL	417
# define	MATCH	418
# define	MINUTE_P	419
# define	MONTH_P	420
# define	NAMES	421
# define	NATIONAL	422
# define	NATURAL	423
# define	NCHAR	424
# define	NEXT	425
# define	NO	426
# define	NOT	427
# define	NULLIF	428
# define	NULL_P	429
# define	NUMERIC	430
# define	OF	431
# define	OFF	432
# define	OLD	433
# define	ON	434
# define	ONLY	435
# define	OPTION	436
# define	OR	437
# define	ORDER	438
# define	OUT	439
# define	OUTER_P	440
# define	OVERLAPS	441
# define	PARTIAL	442
# define	PATH_P	443
# define	POSITION	444
# define	PRECISION	445
# define	PRIMARY	446
# define	PRIOR	447
# define	PRIVILEGES	448
# define	PROCEDURE	449
# define	PUBLIC	450
# define	READ	451
# define	REFERENCES	452
# define	RELATIVE	453
# define	REVOKE	454
# define	RIGHT	455
# define	ROLLBACK	456
# define	SCHEMA	457
# define	SCROLL	458
# define	SECOND_P	459
# define	SELECT	460
# define	SESSION	461
# define	SESSION_USER	462
# define	SET	463
# define	SOME	464
# define	SUBSTRING	465
# define	TABLE	466
# define	TEMPORARY	467
# define	THEN	468
# define	TIME	469
# define	TIMESTAMP	470
# define	TO	471
# define	TRAILING	472
# define	TRANSACTION	473
# define	TRIM	474
# define	TRUE_P	475
# define	UNENCRYPTED	476
# define	UNION	477
# define	UNIQUE	478
# define	UNKNOWN	479
# define	UPDATE	480
# define	USER	481
# define	USING	482
# define	VALUES	483
# define	VARCHAR	484
# define	VARYING	485
# define	VIEW	486
# define	WHEN	487
# define	WHERE	488
# define	WITH	489
# define	WITHOUT	490
# define	WORK	491
# define	YEAR_P	492
# define	ZONE	493
# define	DEFERRABLE	494
# define	DEFERRED	495
# define	IMMEDIATE	496
# define	INITIALLY	497
# define	PENDANT	498
# define	REPLACE	499
# define	RESTRICT	500
# define	TRIGGER	501
# define	COMMITTED	502
# define	SERIALIZABLE	503
# define	TYPE_P	504
# define	ABORT_TRANS	505
# define	ACCESS	506
# define	AFTER	507
# define	AGGREGATE	508
# define	ANALYSE	509
# define	ANALYZE	510
# define	BACKWARD	511
# define	BEFORE	512
# define	BINARY	513
# define	BIT	514
# define	CACHE	515
# define	CHECKPOINT	516
# define	CLUSTER	517
# define	COMMENT	518
# define	COPY	519
# define	CREATEDB	520
# define	CREATEUSER	521
# define	CYCLE	522
# define	DATABASE	523
# define	DELIMITERS	524
# define	DO	525
# define	EACH	526
# define	ENCODING	527
# define	EXCLUSIVE	528
# define	EXPLAIN	529
# define	FORCE	530
# define	FORWARD	531
# define	FREEZE	532
# define	FUNCTION	533
# define	HANDLER	534
# define	INCREMENT	535
# define	INDEX	536
# define	INHERITS	537
# define	INSTEAD	538
# define	ISNULL	539
# define	LANCOMPILER	540
# define	LIMIT	541
# define	LISTEN	542
# define	UNLISTEN	543
# define	LOAD	544
# define	LOCATION	545
# define	LOCK_P	546
# define	MAXVALUE	547
# define	MINVALUE	548
# define	MODE	549
# define	MOVE	550
# define	NEW	551
# define	NOCREATEDB	552
# define	NOCREATEUSER	553
# define	NONE	554
# define	NOTHING	555
# define	NOTIFY	556
# define	NOTNULL	557
# define	OFFSET	558
# define	OIDS	559
# define	OPERATOR	560
# define	OWNER	561
# define	PASSWORD	562
# define	PROCEDURAL	563
# define	REINDEX	564
# define	RENAME	565
# define	RESET	566
# define	RETURNS	567
# define	ROW	568
# define	RULE	569
# define	SEQUENCE	570
# define	SETOF	571
# define	SHARE	572
# define	SHOW	573
# define	START	574
# define	STATEMENT	575
# define	STATISTICS	576
# define	STDIN	577
# define	STDOUT	578
# define	SYSID	579
# define	TEMP	580
# define	TEMPLATE	581
# define	TOAST	582
# define	TRUNCATE	583
# define	TRUSTED	584
# define	UNTIL	585
# define	VACUUM	586
# define	VALID	587
# define	VERBOSE	588
# define	VERSION	589
# define	UNIONJOIN	590
# define	IDENT	591
# define	SCONST	592
# define	Op	593
# define	CSTRING	594
# define	CVARIABLE	595
# define	CPP_LINE	596
# define	IP	597
# define	BITCONST	598
# define	ICONST	599
# define	PARAM	600
# define	FCONST	601
# define	OP	602
# define	ILIKE	603
# define	ESCAPE	604
# define	POSTFIXOP	605
# define	UMINUS	606
# define	YYERROR_VERBOSE	607


extern YYSTYPE yylval;

#endif /* not Y_TAB_H */

==> postgresql_7.2.1.orig.tar.gz: postgresql-7.2.1/src/interfaces/ecpg/preproc/preproc.h <==
#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

#ifndef YYSTYPE
typedef union {
	double                  dval;
	int                     ival;
	char *                  str;
	struct when             action;
	struct index		index;
	int			tagname;
	struct this_type	type;
	enum ECPGttype		type_enum;
	enum ECPGdtype		dtype_enum;
	struct fetch_desc	descriptor;
} yystype;
# define YYSTYPE yystype
#endif
# define	SQL_ALLOCATE	257
# define	SQL_AUTOCOMMIT	258
# define	SQL_BOOL	259
# define	SQL_BREAK	260
# define	SQL_CALL	261
# define	SQL_CARDINALITY	262
# define	SQL_CONNECT	263
# define	SQL_CONNECTION	264
# define	SQL_CONTINUE	265
# define	SQL_COUNT	266
# define	SQL_DATA	267
# define	SQL_DATETIME_INTERVAL_CODE	268
# define	SQL_DATETIME_INTERVAL_PRECISION	269
# define	SQL_DEALLOCATE	270
# define	SQL_DESCRIPTOR	271
# define	SQL_DISCONNECT	272
# define	SQL_ENUM	273
# define	SQL_FOUND	274
# define	SQL_FREE	275
# define	SQL_GET	276
# define	SQL_GO	277
# define	SQL_GOTO	278
# define	SQL_IDENTIFIED	279
# define	SQL_INDICATOR	280
# define	SQL_INT	281
# define	SQL_KEY_MEMBER	282
# define	SQL_LENGTH	283
# define	SQL_LONG	284
# define	SQL_NAME	285
# define	SQL_NULLABLE	286
# define	SQL_OCTET_LENGTH	287
# define	SQL_OPEN	288
# define	SQL_PREPARE	289
# define	SQL_RELEASE	290
# define	SQL_REFERENCE	291
# define	SQL_RETURNED_LENGTH	292
# define	SQL_RETURNED_OCTET_LENGTH	293
# define	SQL_SCALE	294
# define	SQL_SECTION	295
# define	SQL_SHORT	296
# define	SQL_SIGNED	297
# define	SQL_SQL	298
# define	SQL_SQLERROR	299
# define	SQL_SQLPRINT	300
# define	SQL_SQLWARNING	301
# define	SQL_START	302
# define	SQL_STOP	303
# define	SQL_STRUCT	304
# define	SQL_UNSIGNED	305
# define	SQL_VALUE	306
# define	SQL_VAR	307
# define	SQL_WHENEVER	308
# define	S_ADD	309
# define	S_AND	310
# define	S_ANYTHING	311
# define	S_AUTO	312
# define	S_CONST	313
# define	S_DEC	314
# define	S_DIV	315
# define	S_DOTPOINT	316
# define	S_EQUAL	317
# define	S_EXTERN	318
# define	S_INC	319
# define	S_LSHIFT	320
# define	S_MEMPOINT	321
# define	S_MEMBER	322
# define	S_MOD	323
# define	S_MUL	324
# define	S_NEQUAL	325
# define	S_OR	326
# define	S_REGISTER	327
# define	S_RSHIFT	328
# define	S_STATIC	329
# define	S_SUB	330
# define	S_VOLATILE	331
# define	TYPECAST	332
# define	ABSOLUTE	333
# define	ACTION	334
# define	ADD	335
# define	ALL	336
# define	ALTER	337
# define	AND	338
# define	ANY	339
# define	AS	340
# define	ASC	341
# define	AT	342
# define	AUTHORIZATION	343
# define	BEGIN_TRANS	344
# define	BETWEEN	345
# define	BOTH	346
# define	BY	347
# define	CASCADE	348
# define	CASE	349
# define	CAST	350
# define	CHAIN	351
# define	CHAR	352
# define	CHARACTER	353
# define	CHARACTERISTICS	354
# define	CHECK	355
# define	CLOSE	356
# define	COALESCE	357
# define	COLLATE	358
# define	COLUMN	359
# define	COMMIT	360
# define	CONSTRAINT	361
# define	CONSTRAINTS	362
# define	CREATE	363
# define	CROSS	364
# define	CURRENT	365
# define	CURRENT_DATE	366
# define	CURRENT_TIME	367
# define	CURRENT_TIMESTAMP	368
# define	CURRENT_USER	369
# define	CURSOR	370
# define	DAY_P	371
# define	DEC	372
# define	DECIMAL	373
# define	DECLARE	374
# define	DEFAULT	375
# define	DELETE	376
# define	DESC	377
# define	DISTINCT	378
# define	DOUBLE	379
# define	DROP	380
# define	ELSE	381
# define	ENCRYPTED	382
# define	END_TRANS	383
# define	EXCEPT	384
# define	EXECUTE	385
# define	EXISTS	386
# define	EXTRACT	387
# define	FALSE_P	388
# define	FETCH	389
# define	FLOAT	390
# define	FOR	391
# define	FOREIGN	392
# define	FROM	393
# define	FULL	394
# define	GLOBAL	395
# define	GRANT	396
# define	GROUP	397
# define	HAVING	398
# define	HOUR_P	399
# define	IN	400
# define	INNER_P	401
# define	INOUT	402
# define	INSENSITIVE	403
# define	INSERT	404
# define	INTERSECT	405
# define	INTERVAL	406
# define	INTO	407
# define	IS	408
# define	ISOLATION	409
# define	JOIN	410
# define	KEY	411
# define	LANGUAGE	412
# define	LEADING	413
# define	LEFT	414
# define	LEVEL	415
# define	LIKE	416
# define	LOCAL	417
# define	MATCH	418
# define	MINUTE_P	419
# define	MONTH_P	420
# define	NAMES	421
# define	NATIONAL	422
# define	NATURAL	423
# define	NCHAR	424
# define	NEXT	425
# define	NO	426
# define	NOT	427
# define	NULLIF	428
# define	NULL_P	429
# define	NUMERIC	430
# define	OF	431
# define	OFF	432
# define	OLD	433
# define	ON	434
# define	ONLY	435
# define	OPTION	436
# define	OR	437
# define	ORDER	438
# define	OUT	439
# define	OUTER_P	440
# define	OVERLAPS	441
# define	PARTIAL	442
# define	PATH_P	443
# define	POSITION	444
# define	PRECISION	445
# define	PRIMARY	446
# define	PRIOR	447
# define	PRIVILEGES	448
# define	PROCEDURE	449
# define	PUBLIC	450
# define	READ	451
# define	REFERENCES	452
# define	RELATIVE	453
# define	REVOKE	454
# define	RIGHT	455
# define	ROLLBACK	456
# define	SCHEMA	457
# define	SCROLL	458
# define	SECOND_P	459
# define	SELECT	460
# define	SESSION	461
# define	SESSION_USER	462
# define	SET	463
# define	SOME	464
# define	SUBSTRING	465
# define	TABLE	466
# define	TEMPORARY	467
# define	THEN	468
# define	TIME	469
# define	TIMESTAMP	470
# define	TO	471
# define	TRAILING	472
# define	TRANSACTION	473
# define	TRIM	474
# define	TRUE_P	475
# define	UNENCRYPTED	476
# define	UNION	477
# define	UNIQUE	478
# define	UNKNOWN	479
# define	UPDATE	480
# define	USER	481
# define	USING	482
# define	VALUES	483
# define	VARCHAR	484
# define	VARYING	485
# define	VIEW	486
# define	WHEN	487
# define	WHERE	488
# define	WITH	489
# define	WITHOUT	490
# define	WORK	491
# define	YEAR_P	492
# define	ZONE	493
# define	DEFERRABLE	494
# define	DEFERRED	495
# define	IMMEDIATE	496
# define	INITIALLY	497
# define	PENDANT	498
# define	REPLACE	499
# define	RESTRICT	500
# define	TRIGGER	501
# define	COMMITTED	502
# define	SERIALIZABLE	503
# define	TYPE_P	504
# define	ABORT_TRANS	505
# define	ACCESS	506
# define	AFTER	507
# define	AGGREGATE	508
# define	ANALYSE	509
# define	ANALYZE	510
# define	BACKWARD	511
# define	BEFORE	512
# define	BINARY	513
# define	BIT	514
# define	CACHE	515
# define	CHECKPOINT	516
# define	CLUSTER	517
# define	COMMENT	518
# define	COPY	519
# define	CREATEDB	520
# define	CREATEUSER	521
# define	CYCLE	522
# define	DATABASE	523
# define	DELIMITERS	524
# define	DO	525
# define	EACH	526
# define	ENCODING	527
# define	EXCLUSIVE	528
# define	EXPLAIN	529
# define	FORCE	530
# define	FORWARD	531
# define	FREEZE	532
# define	FUNCTION	533
# define	HANDLER	534
# define	INCREMENT	535
# define	INDEX	536
# define	INHERITS	537
# define	INSTEAD	538
# define	ISNULL	539
# define	LANCOMPILER	540
# define	LIMIT	541
# define	LISTEN	542
# define	UNLISTEN	543
# define	LOAD	544
# define	LOCATION	545
# define	LOCK_P	546
# define	MAXVALUE	547
# define	MINVALUE	548
# define	MODE	549
# define	MOVE	550
# define	NEW	551
# define	NOCREATEDB	552
# define	NOCREATEUSER	553
# define	NONE	554
# define	NOTHING	555
# define	NOTIFY	556
# define	NOTNULL	557
# define	OFFSET	558
# define	OIDS	559
# define	OPERATOR	560
# define	OWNER	561
# define	PASSWORD	562
# define	PROCEDURAL	563
# define	REINDEX	564
# define	RENAME	565
# define	RESET	566
# define	RETURNS	567
# define	ROW	568
# define	RULE	569
# define	SEQUENCE	570
# define	SETOF	571
# define	SHARE	572
# define	SHOW	573
# define	START	574
# define	STATEMENT	575
# define	STATISTICS	576
# define	STDIN	577
# define	STDOUT	578
# define	SYSID	579
# define	TEMP	580
# define	TEMPLATE	581
# define	TOAST	582
# define	TRUNCATE	583
# define	TRUSTED	584
# define	UNTIL	585
# define	VACUUM	586
# define	VALID	587
# define	VERBOSE	588
# define	VERSION	589
# define	UNIONJOIN	590
# define	IDENT	591
# define	SCONST	592
# define	Op	593
# define	CSTRING	594
# define	CVARIABLE	595
# define	CPP_LINE	596
# define	IP	597
# define	BITCONST	598
# define	ICONST	599
# define	PARAM	600
# define	FCONST	601
# define	OP	602
# define	ILIKE	603
# define	ESCAPE	604
# define	POSTFIXOP	605
# define	UMINUS	606
# define	YYERROR_VERBOSE	607


extern YYSTYPE yylval;

#endif /* not BISON_Y_TAB_H */
